package
Version:
v1.0.0
Opens a new window with list of versions in this module.
Published: Oct 20, 2025
License: Apache-2.0
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func (s *Set[T]) Add(item T)
func (s *Set[T]) Contains(item T) bool
func (s *Set[T]) Items() []T
func (s *Set[T]) Remove(item T)
Source Files
¶
Click to show internal directories.
Click to hide internal directories.